@@ -130,17 +130,14 @@ class PowerPoint():
             run = paragraph.add_run()
         return run
 
-    def update_chart(self, name,df):
+    def update_chart(self, name:str,df:DataFrame):
         shape = self.get_shape_by_name(name)
         if shape != None:
             titles = list(df.index.values)
-            data = list(df.iloc[:,0])
-            #
-            #data = list(df[1])
-            # data = df.to_numpy()
-            # for i in range(0,len(data)):
-            #     if (isinstance(data[i],str)):
-            #         data[i] = int(data[i].replace(',',''))
+            data=df[df.columns[0]].values.tolist()
+            for i in range(0,len(data)):
+                if (isinstance(data[i],str)):
+                    data[i] = int(data[i].replace(',',''))
 
             if shape.has_chart:
                 chart_data = CategoryChartData()
@@ -148,6 +145,20 @@ class PowerPoint():
                 chart_data.add_series('Series 1', data)
                 shape.chart.replace_data(chart_data)
 
+    def replace_block(self, begin_tag, end_tag, repl_text):
+        for slide in self._prs.slides:
+            for shape in slide.shapes:
+                if shape.has_text_frame:
+                    for paragraph in shape.text_frame.paragraphs:
+                        text = paragraph.text
+                        if text.find(begin_tag)!=-1:
+                            run=self.merge_runs(paragraph)
+                            run_text = run.text
+                            text_prefix = text[:run_text.find(begin_tag)]
+                            text_suffix = text[run_text.find(end_tag)+len(end_tag):]
+                            new_text = text_prefix + repl_text + text_suffix
+                            run.text = run.text.replace(run_text,new_text)
+
 
     """ ***********************************************************************************************************
                                                 Update Table Functionality
@@ -229,7 +240,7 @@ class PowerPoint():
                             test = float(val.replace('%','').strip())
 
                         if (type(val)==str and PowerPoint.isFloat(test) and test < 0) or \
-                           (type(val)==int or type(val)==float and int(val) < 0):
+                           ((type(val)==int or type(val)==float) and int(val) < 0):
                             text_frame = cell.text_frame
                             run = self._merge_runs(text_frame.paragraphs[0])
                             run.font.color.rgb=RGBColor(255,255,255)
@@ -471,3 +482,21 @@ class PowerPoint():
         for shape in slide.shapes:
             if shape.name.find(search_str) != -1: 
                 shape.name = shape.name.replace(search_str,repl_str)
+
+    def get_page_no(self,shape):
+        page_no = 0
+        if shape:
+            while True:
+                shape = self.get_shape_parent(shape)
+                if type(shape).__name__ == 'Slide':
+                    break;
+            
+            page_no = self._prs.slides.index(shape) 
+        return page_no
+
+    def get_shape_parent(self,shape):
+        rslt = None
+        if hasattr(shape,'_parent'):
+            rslt = shape._parent
+        return rslt
+
